@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.025-3-g153ce3a
+package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.026-4-gcfd30c7
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Add contributor names from git to your distribution
 # KEYWORDS: plugin distribution metadata git contributors authors commits
-# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.026';
+our $VERSION = '0.027';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider',
@@ -174,8 +174,15 @@ sub _build_contributors
     $self->log_debug([ 'extracted contributors from git: %s',
         sub { require Data::Dumper; Data::Dumper->new([ \@contributors ])->Indent(2)->Terse(1)->Dump } ]);
 
+    my $fc = "$]" >= '5.016001'
+        ? \&CORE::fc
+        : do {
+            $self->log_debug('case-folding not available; falling back to lower-cased comparisons');
+            sub { lc $_[0] }    # not callable via \&CORE::lc
+        };
+
     # remove duplicates by email address, keeping the latest associated name
-    @contributors = uniq_by { __fc((/(<[^>]+>)/g)[-1]) } @contributors;
+    @contributors = uniq_by { $fc->((/(<[^>]+>)/g)[-1]) } @contributors;
 
     @contributors = Unicode::Collate->new(level => 1)->sort(@contributors) if $self->order_by eq 'name';
 
@@ -190,7 +197,7 @@ sub _build_contributors
 
     if (not $self->include_releaser and my $releaser = $self->_releaser)
     {
-        @contributors = grep { __fc($_) ne __fc($releaser) } @contributors;
+        @contributors = grep { $fc->($_) ne $fc->($releaser) } @contributors;
     }
 
     if ($self->remove)
@@ -252,10 +259,6 @@ sub _git
     return @result;
 }
 
-# use casefolding when available; otherwise, fallback to lower-casing.
-sub __fc { goto ("$]" >= '5.016' ? \&CORE::fc : \&__lc) }
-sub __lc { lc $_[0] }   # not callable via \&CORE::lc
-
 __PACKAGE__->meta->make_immutable;
 
 __END__
@@ -270,7 +273,7 @@ Dist::Zilla::Plugin::Git::Contributors - Add contributor names from git to your
 
 =head1 VERSION
 
-version 0.026
+version 0.027
 
 =head1 SYNOPSIS
 
